@@ -30,10 +30,10 @@ namespace zypp
   //
   //	CLASS NAME : Arch::CompatEntry
   //
-  /** Holds an architecture ID and it's compatible relation.
-   * An architecture is compatibleWith, if it's _idBit is set in
-   * _compatBits. noarch has ID 0, non builtin archs ID 1 and
-   * have to be treated specialy.
+  /** Holds an architecture ID and its compatible relation.
+   * An architecture is compatibleWith, if its _idBit is set in
+   * _compatBits. noarch has ID 0, non-builtin archs have ID 1 and
+   * have to be treated specially.
   */
   struct Arch::CompatEntry
   {
@@ -89,7 +89,7 @@ namespace zypp
     int compare( const CompatEntry & rhs ) const
     {
       if ( _idBit.value() != rhs. _idBit.value() )
-	return( _idBit.value() < rhs. _idBit.value() ? -1 : 1 );
+        return( _idBit.value() < rhs. _idBit.value() ? -1 : 1 );
       return _archStr.compare( rhs._archStr ); // Id 1: non builtin
     }
 
@@ -161,6 +161,9 @@ namespace zypp
   DEF_BUILTIN( i686 );
   DEF_BUILTIN( athlon );
   DEF_BUILTIN( x86_64 );
+  DEF_BUILTIN( x86_64_v2 );
+  DEF_BUILTIN( x86_64_v3 );
+  DEF_BUILTIN( x86_64_v4 );
 
   DEF_BUILTIN( pentium3 );
   DEF_BUILTIN( pentium4 );
@@ -196,9 +199,11 @@ namespace zypp
   DEF_BUILTIN( armv7thl );	/* exists? */
 
   DEF_BUILTIN( armv7hnl );	/* legacy: */DEF_BUILTIN( armv7nhl );
+  DEF_BUILTIN( armv8hl );
   DEF_BUILTIN( armv7hl );
   DEF_BUILTIN( armv6hl );
 
+  DEF_BUILTIN( armv8l );
   DEF_BUILTIN( armv7l );
   DEF_BUILTIN( armv6l );
   DEF_BUILTIN( armv5tejl );
@@ -300,7 +305,7 @@ namespace zypp
         // Define the CompatibleWith relation:
         //
         // NOTE: Order of definition is significant! (Arch::compare)
-	//       - define compatible (less) architectures first!
+        //       - define compatible (less) architectures first!
         //
         defCompatibleWith( a_i386(),		a_noarch() );
         defCompatibleWith( a_i486(),		a_noarch(),a_i386() );
@@ -308,6 +313,9 @@ namespace zypp
         defCompatibleWith( a_i686(),		a_noarch(),a_i386(),a_i486(),a_i586() );
         defCompatibleWith( a_athlon(),		a_noarch(),a_i386(),a_i486(),a_i586(),a_i686() );
         defCompatibleWith( a_x86_64(),		a_noarch(),a_i386(),a_i486(),a_i586(),a_i686(),a_athlon() );
+        defCompatibleWith( a_x86_64_v2(),	a_noarch(),a_i386(),a_i486(),a_i586(),a_i686(),a_athlon(),a_x86_64() );
+        defCompatibleWith( a_x86_64_v3(),	a_noarch(),a_i386(),a_i486(),a_i586(),a_i686(),a_athlon(),a_x86_64(),a_x86_64_v2() );
+        defCompatibleWith( a_x86_64_v4(),	a_noarch(),a_i386(),a_i486(),a_i586(),a_i686(),a_athlon(),a_x86_64(),a_x86_64_v2(),a_x86_64_v3() );
 
         defCompatibleWith( a_pentium3(),	a_noarch(),a_i386(),a_i486(),a_i586(),a_i686() );
         defCompatibleWith( a_pentium4(),	a_noarch(),a_i386(),a_i486(),a_i586(),a_i686(),a_pentium3() );
@@ -333,10 +341,10 @@ namespace zypp
         defCompatibleWith( a_sparc(),		a_noarch() );
         defCompatibleWith( a_sparcv8(),		a_noarch(),a_sparc() );
         defCompatibleWith( a_sparcv9(),		a_noarch(),a_sparc(),a_sparcv8() );
-	defCompatibleWith( a_sparcv9v(),	a_noarch(),a_sparc(),a_sparcv8(),a_sparcv9() );
-	//
+        defCompatibleWith( a_sparcv9v(),	a_noarch(),a_sparc(),a_sparcv8(),a_sparcv9() );
+        //
         defCompatibleWith( a_sparc64(),		a_noarch(),a_sparc(),a_sparcv8(),a_sparcv9() );
-	defCompatibleWith( a_sparc64v(),	a_noarch(),a_sparc(),a_sparcv8(),a_sparcv9(),a_sparcv9v(),a_sparc64() );
+        defCompatibleWith( a_sparc64v(),	a_noarch(),a_sparc(),a_sparcv8(),a_sparcv9(),a_sparcv9v(),a_sparc64() );
         //
         defCompatibleWith( a_armv3l(),		a_noarch() );
         defCompatibleWith( a_armv4l(),		a_noarch(),a_armv3l() );
@@ -347,14 +355,16 @@ namespace zypp
         defCompatibleWith( a_armv5tejl(),	a_noarch(),a_armv3l(),a_armv4l(),a_armv4tl(),a_armv5l(),a_armv5tl(),a_armv5tel() );
         defCompatibleWith( a_armv6l(),		a_noarch(),a_armv3l(),a_armv4l(),a_armv4tl(),a_armv5l(),a_armv5tl(),a_armv5tel(),a_armv5tejl() );
         defCompatibleWith( a_armv7l(),		a_noarch(),a_armv3l(),a_armv4l(),a_armv4tl(),a_armv5l(),a_armv5tl(),a_armv5tel(),a_armv5tejl(),a_armv6l() );
+        defCompatibleWith( a_armv8l(),		a_noarch(),a_armv3l(),a_armv4l(),a_armv4tl(),a_armv5l(),a_armv5tl(),a_armv5tel(),a_armv5tejl(),a_armv6l(),a_armv7l() );
 
         defCompatibleWith( a_armv6hl(),		a_noarch() );
         defCompatibleWith( a_armv7hl(),		a_noarch(),a_armv6hl() );
+        defCompatibleWith( a_armv8hl(),		a_noarch(),a_armv7hl() );
         defCompatibleWith( a_armv7hnl(),	a_noarch(),a_armv7hl(),a_armv6hl() );
-	/*legacy: rpm uses v7hnl */
-	defCompatibleWith( a_armv7nhl(),	a_noarch(),a_armv7hnl(),a_armv7hl(),a_armv6hl() );
+        /*legacy: rpm uses v7hnl */
+        defCompatibleWith( a_armv7nhl(),	a_noarch(),a_armv7hnl(),a_armv7hl(),a_armv6hl() );
 
-	/*?*/defCompatibleWith( a_armv7thl(),	a_noarch(),a_armv7hl() );
+        /*?*/defCompatibleWith( a_armv7thl(),	a_noarch(),a_armv7hl() );
         /*?*/defCompatibleWith( a_armv7tnhl(),	a_noarch(),a_armv7hl(),a_armv7nhl(),a_armv7thl() );
 
         defCompatibleWith( a_aarch64(),		a_noarch() );
@@ -368,10 +378,10 @@ namespace zypp
 
         defCompatibleWith( a_m68k(),		a_noarch() );
 
-	defCompatibleWith( a_mips(),		a_noarch() );
-	defCompatibleWith( a_mipsel(),		a_noarch() );
-	defCompatibleWith( a_mips64(),		a_noarch() );
-	defCompatibleWith( a_mips64el(),	a_noarch() );
+        defCompatibleWith( a_mips(),		a_noarch() );
+        defCompatibleWith( a_mipsel(),		a_noarch() );
+        defCompatibleWith( a_mips64(),		a_noarch() );
+        defCompatibleWith( a_mips64el(),	a_noarch() );
         //
         ///////////////////////////////////////////////////////////////////
         // dumpOn( USR ) << endl;
