@@ -122,8 +122,8 @@ namespace zypp
      * \code
      * Arch::CompatSet cset( Arch::compatSet( Arch_x86_64 ) );
      *
-     * cout << str::join( make_transform_iterator( cset.begin(), std::mem_fun_ref(&Arch::asString) ),
-     *                    make_transform_iterator( cset.end(), std::mem_fun_ref(&Arch::asString) ) )
+     * cout << str::join( make_transform_iterator( cset.begin(), std::mem_fn(&Arch::asString) ),
+     *                    make_transform_iterator( cset.end(), std::mem_fn(&Arch::asString) ) )
      *      << endl;
      *
      * // Prints: x86_64 athlon i686 i586 i486 i386 noarch
@@ -134,8 +134,11 @@ namespace zypp
     /** */
     static std::string asString( const CompatSet & cset )
     {
-      return str::join( make_transform_iterator( cset.begin(), std::mem_fun_ref(&Arch::asString) ),
-                        make_transform_iterator( cset.end(), std::mem_fun_ref(&Arch::asString) ) );
+      // Explicitely select the overload we want, clang seems to choke if there is a static overload for the
+      // member function we want to capture in std::mem_fn (fixes GH-478)
+      const std::string & (Arch::*memfn)( ) const = &Arch::asString;
+      return str::join( make_transform_iterator( cset.begin(), std::mem_fn( memfn ) ),
+                        make_transform_iterator( cset.end(), std::mem_fn( memfn ) ) );
     }
 
   public:
@@ -169,6 +172,12 @@ namespace zypp
   /** \relates Arch */
   extern const Arch Arch_pentium3;
 
+  /** \relates Arch */
+  extern const Arch Arch_x86_64_v4;
+  /** \relates Arch */
+  extern const Arch Arch_x86_64_v3;
+  /** \relates Arch */
+  extern const Arch Arch_x86_64_v2;
   /** \relates Arch */
   extern const Arch Arch_x86_64;
   /** \relates Arch */
@@ -241,6 +250,10 @@ namespace zypp
   /** \relates Arch */
   extern const Arch Arch_armv6hl;
 
+  /** \relates Arch */
+  extern const Arch Arch_armv8hl;
+  /** \relates Arch */
+  extern const Arch Arch_armv8l;
   /** \relates Arch */
   extern const Arch Arch_armv7l;
   /** \relates Arch */
@@ -326,7 +339,7 @@ namespace zypp
   /** Functor finding compatible architectures.
    * \see Arch::compatibleWith
   */
-  struct ArchCompatibleWith : public std::unary_function<Arch,bool>
+  struct ArchCompatibleWith
   {
     /** The target architecture */
     Arch _targetArch;
