@@ -27,7 +27,7 @@
 #include <zypp/repo/ServiceType.h>
 #include <zypp/ServiceInfo.h>
 #include <zypp/RepoStatus.h>
-#include <zypp/ProgressData.h>
+#include <zypp-core/ui/ProgressData>
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp
@@ -563,7 +563,7 @@ namespace zypp
     repo::ServiceType probeService( const Url &url ) const;
 
     /**
-     * Adds new service by it's alias and url
+     * Adds a new service by its alias and URL
      *
      * \param alias unique identifier of the service
      * \param url url to service
@@ -634,6 +634,12 @@ namespace zypp
     void modifyService( const ServiceInfo & service )
     { modifyService( service.alias(), service ); }
 
+    /*!
+     * Checks for any of the given \a urls if there is no geoip data available, caches the results
+     * in the metadata cache for 24hrs. The given urls need to be configured as valid geoIP targets ( usually download.opensuse.org )
+     */
+    void refreshGeoIp ( const RepoInfo::url_set &urls );
+
   private:
     /**
      * Functor thats filter RepoInfo by service which it belongs to.
