@@ -13,10 +13,10 @@
 #include <zypp/base/Logger.h>
 #include <zypp/base/String.h>
 #include <zypp/base/Regex.h>
-#include <zypp/base/InputStream.h>
-#include <zypp/base/UserRequestException.h>
+#include <zypp-core/base/InputStream>
+#include <zypp-core/base/UserRequestException>
 
-#include <zypp/parser/IniDict.h>
+#include <zypp-core/parser/IniDict>
 #include <zypp/parser/ServiceFileReader.h>
 #include <zypp/ServiceInfo.h>
 
@@ -55,7 +55,7 @@ namespace zypp
         MIL << (*its) << endl;
 
         ServiceInfo service(*its);
-	std::map<std::string,std::pair<std::string,ServiceInfo::RepoState>> repoStates;	// <repo_NUM,< alias,RepoState >>
+        std::map<std::string,std::pair<std::string,ServiceInfo::RepoState>> repoStates;	// <repo_NUM,< alias,RepoState >>
 
         for ( IniDict::entry_const_iterator it = dict.entriesBegin(*its);
               it != dict.entriesEnd(*its);
@@ -72,10 +72,10 @@ namespace zypp
             service.setAutorefresh( str::strToTrue( it->second ) );
           else if ( it->first == "type" )
             service.setType( repo::ServiceType(it->second) );
-	  else if ( it->first == "ttl_sec" )
-	    service.setTtl( str::strtonum<Date::Duration>(it->second) );
-	  else if ( it->first == "lrf_dat" )
-	    service.setLrf( Date( it->second ) );
+          else if ( it->first == "ttl_sec" )
+            service.setTtl( str::strtonum<Date::Duration>(it->second) );
+          else if ( it->first == "lrf_dat" )
+            service.setLrf( Date( it->second ) );
           else if ( it->first == "repostoenable" )
           {
             std::vector<std::string> aliases;
@@ -95,50 +95,50 @@ namespace zypp
             }
           }
           else if ( str::startsWith( it->first, "repo_" ) )
-	  {
-	    static str::regex rxexpr( "([0-9]+)(_(.*))?" );
-	    str::smatch what;
-	    if ( str::regex_match( it->first.c_str()+5/*repo_*/, what, rxexpr ) )
-	    {
-	      std::string tag( what[1] );
-	      if (  what.size() > 3 )
-	      {
-		// attribute
-		if ( what[3] == "enabled" )
-		  repoStates[tag].second.enabled = str::strToBool( it->second, repoStates[tag].second.enabled );
-		else if ( what[3] == "autorefresh" )
-		  repoStates[tag].second.autorefresh = str::strToBool( it->second, repoStates[tag].second.autorefresh );
-		else if ( what[3] == "priority" )
-		  str::strtonum( it->second, repoStates[tag].second.priority );
-		else
-		  ERR << "Unknown attribute " << it->first << " ignored" << endl;
-	      }
-	      else
-	      {
-		// alias
-		repoStates[tag].first = it->second;
-	      }
-	    }
-	    else
-	      ERR << "Unknown attribute " << it->first << " ignored" << endl;
-	  }
+          {
+            static str::regex rxexpr( "([0-9]+)(_(.*))?" );
+            str::smatch what;
+            if ( str::regex_match( it->first.c_str()+5/*repo_*/, what, rxexpr ) )
+            {
+              std::string tag( what[1] );
+              if (  what.size() > 3 )
+              {
+                // attribute
+                if ( what[3] == "enabled" )
+                  repoStates[tag].second.enabled = str::strToBool( it->second, repoStates[tag].second.enabled );
+                else if ( what[3] == "autorefresh" )
+                  repoStates[tag].second.autorefresh = str::strToBool( it->second, repoStates[tag].second.autorefresh );
+                else if ( what[3] == "priority" )
+                  str::strtonum( it->second, repoStates[tag].second.priority );
+                else
+                  ERR << "Unknown attribute " << it->first << " ignored" << endl;
+              }
+              else
+              {
+                // alias
+                repoStates[tag].first = it->second;
+              }
+            }
+            else
+              ERR << "Unknown attribute " << it->first << " ignored" << endl;
+          }
           else
             ERR << "Unknown attribute " << it->first << " ignored" << endl;
         }
 
-	if ( ! repoStates.empty() )
-	{
-	  ServiceInfo::RepoStates data;
-	  for ( const auto & el : repoStates )
-	  {
-	    if ( el.second.first.empty() )
-	      ERR << "Missing alias for repo_" << el.first << "; ignore entry" << endl;
-	    else
-	      data[el.second.first] = el.second.second;
-	  }
-	  if ( ! data.empty() )
-	    service.setRepoStates( std::move(data) );
-	}
+        if ( ! repoStates.empty() )
+        {
+          ServiceInfo::RepoStates data;
+          for ( const auto & el : repoStates )
+          {
+            if ( el.second.first.empty() )
+              ERR << "Missing alias for repo_" << el.first << "; ignore entry" << endl;
+            else
+              data[el.second.first] = el.second.second;
+          }
+          if ( ! data.empty() )
+            service.setRepoStates( std::move(data) );
+        }
 
         MIL << "Linking ServiceInfo with file " << file << endl;
         service.setFilepath(file);
