@@ -29,17 +29,18 @@ extern "C"
 #include <vector>
 #include <algorithm>
 
+#include <zypp-core/base/StringV.h>
 #include <zypp/base/Logger.h>
 #include <zypp/base/String.h>
 #include <zypp/base/Gettext.h>
 #include <zypp/base/LocaleGuard.h>
-#include <zypp/base/DtorReset.h>
+#include <zypp-core/base/DtorReset>
 
 #include <zypp/Date.h>
 #include <zypp/Pathname.h>
 #include <zypp/PathInfo.h>
 #include <zypp/PublicKey.h>
-#include <zypp/ProgressData.h>
+#include <zypp-core/ui/ProgressData>
 
 #include <zypp/target/rpm/RpmDb.h>
 #include <zypp/target/rpm/RpmCallbacks.h>
@@ -49,6 +50,7 @@ extern "C"
 #include <zypp/target/rpm/RpmException.h>
 #include <zypp/TmpPath.h>
 #include <zypp/KeyRing.h>
+#include <zypp/KeyManager.h>
 #include <zypp/ZYppFactory.h>
 #include <zypp/ZConfig.h>
 #include <zypp/base/IOTools.h>
@@ -76,8 +78,8 @@ namespace zypp
     inline bool ZYPP_RPM_DEBUG()
     {
       static bool val = [](){
-	const char * env = getenv("ZYPP_RPM_DEBUG");
-	return( env && str::strToBool( env, true ) );
+        const char * env = getenv("ZYPP_RPM_DEBUG");
+        return( env && str::strToBool( env, true ) );
       }();
       return val;
     }
@@ -122,7 +124,7 @@ inline std::string rpmQuoteFilename( const Pathname & path_r )
       // try to prepend cwd
       AutoDispose<char*> cwd( ::get_current_dir_name(), ::free );
       if ( cwd )
-	return Pathname( cwd ) / path_r;
+        return Pathname( cwd ) / path_r;
       WAR << "Can't get cwd!" << endl;
     }
 #endif
@@ -444,17 +446,17 @@ void RpmDb::doRebuildDatabase(callback::SendReport<RebuildDBReport> & report)
     {
       if ( ! str::endsWith( line, ignoreSuffix ) )
       {
-	errmsg += line;
-	errmsg += '\n';
-	WAR << line << endl;
+        errmsg += line;
+        errmsg += '\n';
+        WAR << line << endl;
       }
     }
     else if ( str::startsWith( line, progressPrefix ) )
     {
       if ( ! tics.incr() )
       {
-	WAR << "User requested abort." << endl;
-	systemKill();
+        WAR << "User requested abort." << endl;
+        systemKill();
       }
     }
   }
@@ -484,56 +486,56 @@ namespace
     struct Key
     {
       Key()
-	: _inRpmKeys( nullptr )
-	, _inZyppKeys( nullptr )
+        : _inRpmKeys( nullptr )
+        , _inZyppKeys( nullptr )
       {}
 
       void updateIf( const Edition & rpmKey_r )
       {
-	std::string keyRelease( rpmKey_r.release() );
-	int comp = _release.compare( keyRelease );
-	if ( comp < 0 )
-	{
-	  // update to newer release
-	  _release.swap( keyRelease );
-	  _inRpmKeys  = &rpmKey_r;
-	  _inZyppKeys = nullptr;
-	  if ( !keyRelease.empty() )
-	    DBG << "Old key in Z: gpg-pubkey-" << rpmKey_r.version() << "-" <<  keyRelease << endl;
-	}
-	else if ( comp == 0 )
-	{
-	  // stay with this release
-	  if ( ! _inRpmKeys )
-	    _inRpmKeys = &rpmKey_r;
-	}
-	// else: this is an old release
-	else
-	  DBG << "Old key in R: gpg-pubkey-" << rpmKey_r.version() << "-" <<  keyRelease << endl;
+        std::string keyRelease( rpmKey_r.release() );
+        int comp = _release.compare( keyRelease );
+        if ( comp < 0 )
+        {
+          // update to newer release
+          _release.swap( keyRelease );
+          _inRpmKeys  = &rpmKey_r;
+          _inZyppKeys = nullptr;
+          if ( !keyRelease.empty() )
+            DBG << "Old key in Z: gpg-pubkey-" << rpmKey_r.version() << "-" <<  keyRelease << endl;
+        }
+        else if ( comp == 0 )
+        {
+          // stay with this release
+          if ( ! _inRpmKeys )
+            _inRpmKeys = &rpmKey_r;
+        }
+        // else: this is an old release
+        else
+          DBG << "Old key in R: gpg-pubkey-" << rpmKey_r.version() << "-" <<  keyRelease << endl;
       }
 
       void updateIf( const PublicKeyData & zyppKey_r )
       {
-	std::string keyRelease( zyppKey_r.gpgPubkeyRelease() );
-	int comp = _release.compare( keyRelease );
-	if ( comp < 0 )
-	{
-	  // update to newer release
-	  _release.swap( keyRelease );
-	  _inRpmKeys  = nullptr;
-	  _inZyppKeys = &zyppKey_r;
-	  if ( !keyRelease.empty() )
-	    DBG << "Old key in R: gpg-pubkey-" << zyppKey_r.gpgPubkeyVersion() << "-" << keyRelease << endl;
-	}
-	else if ( comp == 0 )
-	{
-	  // stay with this release
-	  if ( ! _inZyppKeys )
-	    _inZyppKeys = &zyppKey_r;
-	}
-	// else: this is an old release
-	else
-	  DBG << "Old key in Z: gpg-pubkey-" << zyppKey_r.gpgPubkeyVersion() << "-" << keyRelease << endl;
+        std::string keyRelease( zyppKey_r.gpgPubkeyRelease() );
+        int comp = _release.compare( keyRelease );
+        if ( comp < 0 )
+        {
+          // update to newer release
+          _release.swap( keyRelease );
+          _inRpmKeys  = nullptr;
+          _inZyppKeys = &zyppKey_r;
+          if ( !keyRelease.empty() )
+            DBG << "Old key in R: gpg-pubkey-" << zyppKey_r.gpgPubkeyVersion() << "-" << keyRelease << endl;
+        }
+        else if ( comp == 0 )
+        {
+          // stay with this release
+          if ( ! _inZyppKeys )
+            _inZyppKeys = &zyppKey_r;
+        }
+        // else: this is an old release
+        else
+          DBG << "Old key in Z: gpg-pubkey-" << zyppKey_r.gpgPubkeyVersion() << "-" << keyRelease << endl;
       }
 
       std::string _release;
@@ -562,14 +564,14 @@ namespace
     {
       DBG << "gpg-pubkey-" << (*it).first << "-" << (*it).second._release << " "
           << ( (*it).second._inRpmKeys  ? "R" : "_" )
-	  << ( (*it).second._inZyppKeys ? "Z" : "_" ) << endl;
+          << ( (*it).second._inZyppKeys ? "Z" : "_" ) << endl;
       if ( ! (*it).second._inRpmKeys )
       {
-	zyppKeys.push_back( *(*it).second._inZyppKeys );
+        zyppKeys.push_back( *(*it).second._inZyppKeys );
       }
       if ( ! (*it).second._inZyppKeys )
       {
-	rpmKeys.insert( *(*it).second._inRpmKeys );
+        rpmKeys.insert( *(*it).second._inRpmKeys );
       }
     }
     rpmKeys_r.swap( rpmKeys );
@@ -602,9 +604,9 @@ void RpmDb::syncTrustedKeys( SyncTrustedKeyBits mode_r )
     {
       if ( ! rpmKeys.count( keyData.gpgPubkeyEdition() ) )
       {
-	DBG << "Excess key in Z to delete: gpg-pubkey-" << keyData.gpgPubkeyEdition() << endl;
-	getZYpp()->keyRing()->deleteKey( keyData.id(), /*trusted*/true );
-	if ( !dirty ) dirty = true;
+        DBG << "Excess key in Z to delete: gpg-pubkey-" << keyData.gpgPubkeyEdition() << endl;
+        getZYpp()->keyRing()->deleteKey( keyData.id(), /*trusted*/true );
+        if ( !dirty ) dirty = true;
       }
     }
     if ( dirty )
@@ -629,10 +631,10 @@ void RpmDb::syncTrustedKeys( SyncTrustedKeyBits mode_r )
       std::ofstream tmpos( tmpfile.path().c_str() );
       for_( it, rpmKeys.begin(), rpmKeys.end() )
       {
-	// we export the rpm key into a file
-	RpmHeader::constPtr result;
-	getData( "gpg-pubkey", *it, result );
-	tmpos << result->tag_description() << endl;
+        // we export the rpm key into a file
+        RpmHeader::constPtr result;
+        getData( "gpg-pubkey", *it, result );
+        tmpos << result->tag_description() << endl;
       }
     }
     try
@@ -644,10 +646,10 @@ void RpmDb::syncTrustedKeys( SyncTrustedKeyBits mode_r )
       std::set<Edition> missingKeys;
       for ( const Edition & key : rpmKeys )
       {
-	if ( getZYpp()->keyRing()->isKeyTrusted( key.version() ) ) // key.version is the gpgkeys short ID
-	  continue;
-	ERR << "Could not import key:" << str::Format("gpg-pubkey-%s") % key << " into zypp keyring (V3 key?)" << endl;
-	missingKeys.insert( key );
+        if ( getZYpp()->keyRing()->isKeyTrusted( key.version() ) ) // key.version is the gpgkeys short ID
+          continue;
+        ERR << "Could not import key:" << str::Format("gpg-pubkey-%s") % key << " into zypp keyring (V3 key?)" << endl;
+        missingKeys.insert( key );
       }
       if ( ! missingKeys.empty() )
         callback::SendReport<KeyRingReport>()->reportNonImportedKeys(missingKeys);
@@ -668,11 +670,11 @@ void RpmDb::syncTrustedKeys( SyncTrustedKeyBits mode_r )
     {
       try
       {
-	importPubkey( getZYpp()->keyRing()->exportTrustedPublicKey( *it ) );
+        importPubkey( getZYpp()->keyRing()->exportTrustedPublicKey( *it ) );
       }
       catch ( const RpmException & exp )
       {
-	ZYPP_CAUGHT( exp );
+        ZYPP_CAUGHT( exp );
       }
     }
   }
@@ -818,8 +820,8 @@ void RpmDb::removePubkey( const PublicKey & pubkey_r )
   {
     if ( (*it).version() == pubkeyVersion )
     {
-	found_edition = it;
-	break;
+        found_edition = it;
+        break;
     }
   }
 
@@ -1107,50 +1109,50 @@ void RpmDb::getData( const std::string & name_r, const Edition & ed_r,
 ///////////////////////////////////////////////////////////////////
 namespace
 {
-  struct RpmlogCapture : public std::string
+  struct RpmlogCapture : public std::vector<std::string>
   {
     RpmlogCapture()
-    { rpmlog()._cap = this; }
+    {
+      rpmlogSetCallback( rpmLogCB, this );
+      _oldMask = rpmlogSetMask( RPMLOG_UPTO( RPMLOG_PRI(RPMLOG_INFO) ) );
+    }
 
     ~RpmlogCapture()
-    { rpmlog()._cap = nullptr; }
+    {
+      rpmlogSetCallback( nullptr, nullptr );
+      rpmlogSetMask( _oldMask );
+    }
+
+    static int rpmLogCB( rpmlogRec rec_r, rpmlogCallbackData data_r )
+    { return reinterpret_cast<RpmlogCapture*>(data_r)->rpmLog( rec_r ); }
+
+    int rpmLog( rpmlogRec rec_r )
+    {
+      std::string l { ::rpmlogRecMessage( rec_r ) };  // NL terminated line!
+      l.pop_back(); // strip trailing NL
+      push_back( std::move(l) );
+      return 0;
+    }
 
   private:
-    struct Rpmlog
-    {
-      Rpmlog()
-      : _cap( nullptr )
-      {
-	rpmlogSetCallback( rpmLogCB, this );
-	rpmSetVerbosity( RPMLOG_INFO );
-	_f = ::fopen( "/dev/null","w");
-	rpmlogSetFile( _f );
-      }
-
-      ~Rpmlog()
-      { if ( _f ) ::fclose( _f ); }
-
-      static int rpmLogCB( rpmlogRec rec_r, rpmlogCallbackData data_r )
-      { return reinterpret_cast<Rpmlog*>(data_r)->rpmLog( rec_r ); }
-
-      int rpmLog( rpmlogRec rec_r )
-      {
-	if ( _cap ) (*_cap) += rpmlogRecMessage( rec_r );
-	return RPMLOG_DEFAULT;
-      }
-
-      FILE * _f;
-      std::string * _cap;
-    };
-
-    static Rpmlog & rpmlog()
-    { static Rpmlog _rpmlog; return _rpmlog; }
+    int _oldMask = 0;
   };
 
+  std::ostream & operator<<( std::ostream & str, const RpmlogCapture & obj )
+  {
+    char sep = '\0';
+    for ( const auto & l : obj ) {
+      if ( sep ) str << sep; else sep = '\n';
+      str << l;
+    }
+    return str;
+  }
+
+
   RpmDb::CheckPackageResult doCheckPackageSig( const Pathname & path_r,			// rpm file to check
-					       const Pathname & root_r,			// target root
-					       bool  requireGPGSig_r,			// whether no gpg signature is to be reported
-					       RpmDb::CheckPackageDetail & detail_r )	// detailed result
+                                               const Pathname & root_r,			// target root
+                                               bool  requireGPGSig_r,			// whether no gpg signature is to be reported
+                                               RpmDb::CheckPackageDetail & detail_r )	// detailed result
   {
     PathInfo file( path_r );
     if ( ! file.isFile() )
@@ -1164,66 +1166,86 @@ namespace
     {
       ERR << "Can't open file for reading: " << file << " (" << ::Fstrerror(fd) << ")" << endl;
       if ( fd )
-	::Fclose( fd );
+        ::Fclose( fd );
       return RpmDb::CHK_ERROR;
     }
     rpmts ts = ::rpmtsCreate();
     ::rpmtsSetRootDir( ts, root_r.c_str() );
     ::rpmtsSetVSFlags( ts, RPMVSF_DEFAULT );
-
-    rpmQVKArguments_s qva;
-    memset( &qva, 0, sizeof(rpmQVKArguments_s) );
-#ifdef HAVE_NO_RPMTSSETVFYFLAGS
-    // Legacy: In rpm >= 4.15 qva_flags symbols don't exist
-    // and qva_flags is not used in signature checking at all.
-    qva.qva_flags = (VERIFY_DIGEST|VERIFY_SIGNATURE);
-#else
+#ifdef HAVE_RPM_VERIFY_TRANSACTION_STEP
     ::rpmtsSetVfyFlags( ts, RPMVSF_DEFAULT );
 #endif
+
     RpmlogCapture vresult;
     LocaleGuard guard( LC_ALL, "C" );	// bsc#1076415: rpm log output is localized, but we need to parse it :(
+    static rpmQVKArguments_s qva = ([](){ rpmQVKArguments_s qva; memset( &qva, 0, sizeof(rpmQVKArguments_s) ); return qva; })();
     int res = ::rpmVerifySignatures( &qva, ts, fd, path_r.basename().c_str() );
     guard.restore();
 
     ts = rpmtsFree(ts);
     ::Fclose( fd );
 
-    // results per line...
-    //     Header V3 RSA/SHA256 Signature, key ID 3dbdc284: OK
-    //     Header SHA1 digest: OK (a60386347863affefef484ff1f26c889373eb094)
-    //     V3 RSA/SHA256 Signature, key ID 3dbdc284: OK
-    //     MD5 digest: OK (fd5259fe677a406951dcb2e9d08c4dcc)
-    //
-    // TODO: try to get SIG info from the header rather than parsing the output
-    std::vector<std::string> lines;
-    str::split( vresult, std::back_inserter(lines), "\n" );
+    // Check the individual signature/disgest results:
+
+    // To.map back known result strings to enum, everything else is CHK_ERROR.
+    typedef std::map<std::string_view,RpmDb::CheckPackageResult> ResultMap;
+    static const ResultMap resultMap {
+      { "OK",         RpmDb::CHK_OK },
+      { "NOKEY",      RpmDb::CHK_NOKEY },
+      { "BAD",        RpmDb::CHK_FAIL },
+      { "UNKNOWN",    RpmDb::CHK_NOTFOUND },
+      { "NOTRUSTED",  RpmDb::CHK_NOTTRUSTED },
+      { "NOTFOUND",   RpmDb::CHK_NOTFOUND },
+    };
+    auto getresult = []( const ResultMap & resultMap, ResultMap::key_type key )->ResultMap::mapped_type {
+      auto it = resultMap.find( key );
+      return it != resultMap.end() ? it->second : RpmDb::CHK_ERROR;
+    };
+
+    // To track the signature states we saw.
     unsigned count[7] = { 0, 0, 0, 0, 0, 0, 0 };
 
-    for ( unsigned i = 1; i < lines.size(); ++i )
+    // To track the kind off sigs we saw.
+    enum Saw {
+      SawNone          = 0,
+      SawHeaderSig     = (1 << 0),  // Header V3 RSA/SHA256 Signature, key ID 3dbdc284: OK
+      SawHeaderDigest  = (1 << 1),  // Header SHA1 digest: OK (a60386347863affefef484ff1f26c889373eb094)
+      SawPayloadDigest = (1 << 2),  // Payload SHA256 digest: OK
+      SawSig           = (1 << 3),  // V3 RSA/SHA256 Signature, key ID 3dbdc284: OK
+      SawDigest        = (1 << 4),  // MD5 digest: OK (fd5259fe677a406951dcb2e9d08c4dcc)
+    };
+    unsigned saw = SawNone;
+
+    static const str::regex rx( "^ *(Header|Payload)? .*(Signature, key|digest).*: ([A-Z]+)" );
+    str::smatch what;
+    for ( const std::string & line : vresult )
     {
-      std::string & line( lines[i] );
+      if ( line[0] != ' ' ) // result lines are indented
+        continue;
+
       RpmDb::CheckPackageResult lineres = RpmDb::CHK_ERROR;
-      if ( line.find( ": OK" ) != std::string::npos )
-      {
-	lineres = RpmDb::CHK_OK;
-	if ( line.find( "Signature, key ID" ) == std::string::npos )
-	  ++count[RpmDb::CHK_NOSIG];	// Valid but no gpg signature -> CHK_NOSIG
+      if ( str::regex_match( line, what, rx ) ) {
+
+        lineres = getresult( resultMap, what[3] );
+        if ( lineres == RpmDb::CHK_NOTFOUND )
+          continue; // just collect details for signatures found (#229)
+
+        if ( what[1][0] == 'H' ) {
+          saw |= ( what[2][0] == 'S' ? SawHeaderSig :SawHeaderDigest );
+        }
+        else if ( what[1][0] == 'P' ) {
+          if ( what[2][0] == 'd' ) saw |= SawPayloadDigest;
+        }
+        else {
+          saw |= ( what[2][0] == 'S' ? SawSig : SawDigest );
+        }
       }
-      else if ( line.find( ": NOKEY" ) != std::string::npos )
-      { lineres = RpmDb::CHK_NOKEY; }
-      else if ( line.find( ": BAD" ) != std::string::npos )
-      { lineres = RpmDb::CHK_FAIL; }
-      else if ( line.find( ": UNKNOWN" ) != std::string::npos )
-      { lineres = RpmDb::CHK_NOTFOUND; }
-      else if ( line.find( ": NOTRUSTED" ) != std::string::npos )
-      { lineres = RpmDb::CHK_NOTTRUSTED; }
-      else if ( line.find( ": NOTFOUND" ) != std::string::npos )
-      { continue; } // just collect details for signatures found (#229)
 
       ++count[lineres];
       detail_r.push_back( RpmDb::CheckPackageDetail::value_type( lineres, std::move(line) ) );
     }
 
+    // Now combine the overall result:
     RpmDb::CheckPackageResult ret = ( res ? RpmDb::CHK_ERROR : RpmDb::CHK_OK );
 
     if ( count[RpmDb::CHK_FAIL] )
@@ -1238,20 +1260,82 @@ namespace
     else if ( count[RpmDb::CHK_NOTTRUSTED] )
       ret = RpmDb::CHK_NOTTRUSTED;
 
-    else if ( ret == RpmDb::CHK_OK )
-    {
-      if ( count[RpmDb::CHK_OK] == count[RpmDb::CHK_NOSIG]  )
-      {
-	detail_r.push_back( RpmDb::CheckPackageDetail::value_type( RpmDb::CHK_NOSIG, std::string("    ")+_("Package is not signed!") ) );
-	if ( requireGPGSig_r )
-	  ret = RpmDb::CHK_NOSIG;
+    else if ( ret == RpmDb::CHK_OK ) {
+      // Everything is OK, so check whether it's sufficient.
+      // bsc#1184501: To count as signed the package needs a header signature
+      // and either a payload digest (secured by the header sig) or a content signature.
+      bool isSigned = (saw & SawHeaderSig) && ( (saw & SawPayloadDigest) || (saw & SawSig) );
+      if ( not isSigned ) {
+        std::string message { "    " };
+        if ( not (saw & SawHeaderSig) )
+          message += _("Package header is not signed!");
+        else
+          message += _("Package payload is not signed!");
+
+        detail_r.push_back( RpmDb::CheckPackageDetail::value_type( RpmDb::CHK_NOSIG, std::move(message) ) );
+        if ( requireGPGSig_r )
+          ret = RpmDb::CHK_NOSIG;
       }
     }
 
     if ( ret != RpmDb::CHK_OK )
     {
+      // In case of an error line results may be reported to the user. In case rpm printed
+      // only 8byte key IDs to stdout we try to get longer IDs from the header.
+      bool didReadHeader = false;
+      std::unordered_map< std::string, std::string> fprs;
+
+      // we replace the data only if the key IDs are actually only 8 bytes
+      str::regex rxexpr( "key ID ([a-fA-F0-9]{8}):" );
+      for ( auto &detail : detail_r ) {
+        auto &line = detail.second;
+        str::smatch what;
+        if ( str::regex_match( line, what, rxexpr ) ) {
+
+          if ( !didReadHeader ) {
+            didReadHeader = true;
+
+            // Get signature info from the package header, RPM always prints only the 8 byte ID
+            auto header = RpmHeader::readPackage( path_r, RpmHeader::NOVERIFY );
+            if ( header ) {
+              auto keyMgr = zypp::KeyManagerCtx::createForOpenPGP();
+              const auto &addFprs = [&]( auto tag ){
+                const auto &list1 = keyMgr.readSignatureFingerprints( header->blob_val( tag ) );
+                for ( const auto &id : list1 ) {
+                  if ( id.size() <= 8 )
+                    continue;
+
+                  const auto &lowerId = str::toLower( id );
+                  fprs.insert( std::make_pair( lowerId.substr( lowerId.size() - 8 ), lowerId ) );
+                }
+              };
+
+              addFprs( RPMTAG_SIGGPG );
+              addFprs( RPMTAG_SIGPGP );
+              addFprs( RPMTAG_RSAHEADER );
+              addFprs( RPMTAG_DSAHEADER );
+
+            } else {
+              ERR << "Failed to read package signatures." << std::endl;
+            }
+          }
+
+          // if we have no keys we can substitute we can leave the loop right away
+          if ( !fprs.size() )
+            break;
+
+          {
+            // replace the short key ID with the long ones parsed from the header
+            const auto &keyId = str::toLower( what[1] );
+            if ( const auto &i = fprs.find( keyId ); i != fprs.end() ) {
+              str::replaceAll( line, keyId, i->second );
+            }
+          }
+        }
+      }
+
       WAR << path_r << " (" << requireGPGSig_r << " -> " << ret << ")" << endl;
-      WAR << vresult;
+      WAR << vresult << endl;
     }
     else
       DBG << path_r << " [0-Signature is OK]" << endl;
@@ -1332,7 +1416,6 @@ RpmDb::queryChangedFiles(FileList & fileList, const std::string& packageName)
 }
 
 
-
 /****************************************************************/
 /* private member-functions					*/
 /****************************************************************/
@@ -1412,6 +1495,7 @@ bool RpmDb::systemReadLine( std::string & line )
 
           // we might have received a partial line, lets not forget about it
           line += readResult.second;
+          break;
         }
         case io::ReceiveUpToResult::Error:
         case io::ReceiveUpToResult::EndOfFile: {
@@ -1605,7 +1689,6 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
 
   MIL << "RpmDb::installPackage(" << filename << "," << flags << ")" << endl;
 
-
   // backup
   if ( _packagebackups )
   {
@@ -1669,7 +1752,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
   cmdout.set( "lineno", lineno );
 
   // LEGACY: collect and forward additional rpm output in finish
-  std::string rpmmsg;				// TODO: immediately forward lines via Callback::report rather than collecting
+  std::string rpmmsg;
   std::vector<std::string> configwarnings;	// TODO: immediately process lines rather than collecting
 
   while ( systemReadLine( line ) )
@@ -1687,7 +1770,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
 
     if ( lineno >= MAXRPMMESSAGELINES ) {
       if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
-	continue;
+        continue;
     }
 
     rpmmsg += line+'\n';
@@ -1725,7 +1808,10 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
     sstr << "rpm output:" << endl << rpmmsg << endl;
     historylog.comment(sstr.str());
     // TranslatorExplanation the colon is followed by an error message
-    ZYPP_THROW(RpmSubprocessException(_("RPM failed: ") + (rpmmsg.empty() ? error_message : rpmmsg) ));
+    auto excpt { RpmSubprocessException(_("RPM failed: ") + error_message ) };
+    if ( not rpmmsg.empty() )
+      excpt.addHistory( rpmmsg );
+    ZYPP_THROW(std::move(excpt));
   }
   else if ( ! rpmmsg.empty() )
   {
@@ -1736,7 +1822,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, cal
     sstr << "Additional rpm output:" << endl << rpmmsg << endl;
     historylog.comment(sstr.str());
 
-    // report additional rpm output in finish
+    // report additional rpm output in finish (LEGACY! Lines are immediately reported as InstallResolvableReport::contentRpmout)
     // TranslatorExplanation Text is followed by a ':'  and the actual output.
     report->finishInfo(str::form( "%s:\n%s\n", _("Additional rpm output"),  rpmmsg.c_str() ));
   }
@@ -1849,7 +1935,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
 
 
   // LEGACY: collect and forward additional rpm output in finish
-  std::string rpmmsg;		// TODO: immediately forward lines via Callback::report rather than collecting
+  std::string rpmmsg;
 
   // got no progress from command, so we fake it:
   // 5  - command started
@@ -1864,7 +1950,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
 
     if ( lineno >= MAXRPMMESSAGELINES ) {
       if ( line.find( " scriptlet failed, " ) == std::string::npos )	// always log %script errors
-	continue;
+        continue;
     }
     rpmmsg += line+'\n';
   }
@@ -1881,7 +1967,10 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
     sstr << "rpm output:" << endl << rpmmsg << endl;
     historylog.comment(sstr.str());
     // TranslatorExplanation the colon is followed by an error message
-    ZYPP_THROW(RpmSubprocessException(_("RPM failed: ") + (rpmmsg.empty() ? error_message: rpmmsg) ));
+    auto excpt { RpmSubprocessException(_("RPM failed: ") + error_message ) };
+    if ( not rpmmsg.empty() )
+      excpt.addHistory( rpmmsg );
+    ZYPP_THROW(std::move(excpt));
   }
   else if ( ! rpmmsg.empty() )
   {
@@ -1892,7 +1981,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, cal
     sstr << "Additional rpm output:" << endl << rpmmsg << endl;
     historylog.comment(sstr.str());
 
-    // report additional rpm output in finish
+    // report additional rpm output in finish (LEGACY! Lines are immediately reported as RemoveResolvableReport::contentRpmout)
     // TranslatorExplanation Text is followed by a ':'  and the actual output.
     report->finishInfo(str::form( "%s:\n%s\n", _("Additional rpm output"),  rpmmsg.c_str() ));
   }
@@ -2018,7 +2107,7 @@ bool RpmDb::backupPackage(const std::string& packageName)
 
     std::string tarmsg;
 
-    // TODO: its probably possible to start tar with -v and watch it adding
+    // TODO: it is probably possible to start tar with -v and watch it adding
     // files to report progress
     for (std::string output = tar.receiveLine(); output.length() ;output = tar.receiveLine())
     {
